pub enum Error {
CellSyntaxError {
filename: PathBuf,
position: Address,
parse_error: Box<ParseError>,
},
CodeSyntaxError {
filename: PathBuf,
parse_error: Box<ParseError>,
},
EvalError {
message: String,
filename: PathBuf,
position: Address,
},
GoogleSetupError(String),
InitError(String),
ModifierSyntaxError {
filename: PathBuf,
parse_error: Box<ParseError>,
position: Address,
},
ObjectWriteError {
filename: PathBuf,
message: String,
},
SourceCodeError {
filename: PathBuf,
message: String,
},
TargetWriteError {
message: String,
output: Output,
},
}Expand description
The various kinds of errors that can occur during compilation and evaluation of a csv++ template.
Variants
CellSyntaxError
A syntax error in a formula in a cell.
CodeSyntaxError
A syntax error in the code section.
EvalError
An error encountered when evaluating the formulas in a cell. For example if a builtin funciton is called with the wrong number of arguments.
GoogleSetupError(String)
Google Sheets requires that the gcloud CLI tools are installed and configured. If we
think they’re not, this message includes a lot of details about setting them up. So
it’s very Google Sheets-specific.
InitError(String)
An error while building the runtime or reading the source code. These are typically not due to user error.
ModifierSyntaxError
A syntax error encountered while parsing the modifiers of a cell.
ObjectWriteError
An error encountered while serializing the compiled template to an object file.
SourceCodeError
An error ecountered reaading or doing an initial parse of the source code.
TargetWriteError
An error encountered while writing to the target.