Struct csvpp::ModulePath
source · pub struct ModulePath(/* private fields */);Trait Implementations
sourceimpl Clone for ModulePath
impl Clone for ModulePath
sourcefn clone(&self) -> ModulePath
fn clone(&self) -> ModulePath
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ModulePath
impl Debug for ModulePath
sourceimpl<'de> Deserialize<'de> for ModulePath
impl<'de> Deserialize<'de> for ModulePath
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for ModulePath
impl Display for ModulePath
sourceimpl From<ModulePath> for PathBuf
impl From<ModulePath> for PathBuf
sourcefn from(mn: ModulePath) -> PathBuf
fn from(mn: ModulePath) -> PathBuf
Converts to this type from the input type.
sourceimpl Hash for ModulePath
impl Hash for ModulePath
sourceimpl Ord for ModulePath
impl Ord for ModulePath
sourcefn cmp(&self, other: &ModulePath) -> Ordering
fn cmp(&self, other: &ModulePath) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for ModulePath
impl PartialEq for ModulePath
sourcefn eq(&self, other: &ModulePath) -> bool
fn eq(&self, other: &ModulePath) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ModulePath
impl PartialOrd for ModulePath
sourcefn partial_cmp(&self, other: &ModulePath) -> Option<Ordering>
fn partial_cmp(&self, other: &ModulePath) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for ModulePath
impl Serialize for ModulePath
sourceimpl TryFrom<PathBuf> for ModulePath
impl TryFrom<PathBuf> for ModulePath
impl Eq for ModulePath
impl StructuralPartialEq for ModulePath